@@ -48,6 +48,7 @@ enum
 {
   PROP_0,
   PROP_CAMERA_NAME,
+  PROP_CAMERA,
   PROP_GAIN,
   PROP_GAIN_AUTO,
   PROP_EXPOSURE,
@@ -70,7 +71,7 @@ gst_aravis_get_all_camera_caps (GstAravis *gst_aravis)
 {
 	GstCaps *caps;
 	gint64 *pixel_formats;
-	double frame_rate;
+	double min_frame_rate, max_frame_rate;
 	int min_height, min_width;
 	int max_height, max_width;
 	unsigned int n_pixel_formats, i;
@@ -85,6 +86,15 @@ gst_aravis_get_all_camera_caps (GstAravis *gst_aravis)
 	arv_camera_get_width_bounds (gst_aravis->camera, &min_width, &max_width);
 	arv_camera_get_height_bounds (gst_aravis->camera, &min_height, &max_height);
 	pixel_formats = arv_camera_get_available_pixel_formats (gst_aravis->camera, &n_pixel_formats);
+	arv_camera_get_frame_rate_bounds (gst_aravis->camera, &min_frame_rate, &max_frame_rate);
+
+	int min_frame_rate_numerator;
+	int min_frame_rate_denominator;
+	gst_util_double_to_fraction (min_frame_rate, &min_frame_rate_numerator, &min_frame_rate_denominator);
+
+	int max_frame_rate_numerator;
+	int max_frame_rate_denominator;
+	gst_util_double_to_fraction (max_frame_rate, &max_frame_rate_numerator, &max_frame_rate_denominator);
 
 	caps = gst_caps_new_empty ();
 	for (i = 0; i < n_pixel_formats; i++) {
@@ -99,7 +109,9 @@ gst_aravis_get_all_camera_caps (GstAravis *gst_aravis)
 			gst_structure_set (structure,
 					   "width", GST_TYPE_INT_RANGE, min_width, max_width,
 					   "height", GST_TYPE_INT_RANGE, min_height, max_height,
-					   "framerate", GST_TYPE_FRACTION_RANGE, 0, 1, G_MAXINT, 1,
+					   "framerate", GST_TYPE_FRACTION_RANGE,
+							   min_frame_rate_numerator, min_frame_rate_denominator,
+							   max_frame_rate_numerator, max_frame_rate_denominator,
 					   NULL);
 			gst_caps_append_structure (caps, structure);
 		}
@@ -151,10 +163,19 @@ gst_aravis_set_caps (GstBaseSrc *src, GstCaps *caps)
 	gst_structure_get_int (structure, "width", &width);
 	gst_structure_get_int (structure, "height", &height);
 	frame_rate = gst_structure_get_value (structure, "framerate");
-	gst_structure_get_fourcc (structure, "format", &fourcc);
 	gst_structure_get_int (structure, "bpp", &bpp);
 	gst_structure_get_int (structure, "depth", &depth);
 
+	if (gst_structure_get_field_type (structure, "format") == G_TYPE_STRING) {
+		const char *string;
+
+	       	string = gst_structure_get_string (structure, "format");
+		fourcc = GST_STR_FOURCC (string);
+	} else if (gst_structure_get_field_type (structure, "format") == GST_TYPE_FOURCC) {
+		gst_structure_get_fourcc (structure, "format", &fourcc);
+	} else
+		fourcc = 0;
+
 	pixel_format = arv_pixel_format_from_gst_caps (gst_structure_get_name (structure), bpp, depth, fourcc);
 
 	arv_camera_set_region (gst_aravis->camera, gst_aravis->offset_x, gst_aravis->offset_y, width, height);
@@ -246,6 +267,28 @@ gst_aravis_set_caps (GstBaseSrc *src, GstCaps *caps)
 	return TRUE;
 }
 
+void
+gst_aravis_init_camera (GstAravis *gst_aravis)
+{
+	if (gst_aravis->camera != NULL)
+		g_object_unref (gst_aravis->camera);
+
+	gst_aravis->camera = arv_camera_new (gst_aravis->camera_name);
+
+	gst_aravis->gain = arv_camera_get_gain(gst_aravis->camera);
+	gst_aravis->gain_auto = arv_camera_is_gain_available(gst_aravis->camera);
+
+	gst_aravis->exposure_time_us = arv_camera_get_exposure_time(gst_aravis->camera);
+	if (arv_camera_get_exposure_time_auto(gst_aravis->camera) == ARV_AUTO_OFF)
+		gst_aravis->exposure_auto = FALSE;
+	else
+		gst_aravis->exposure_auto = TRUE;
+
+	arv_camera_get_region (gst_aravis->camera, &gst_aravis->offset_x, &gst_aravis->offset_y, NULL, NULL);
+	arv_camera_get_binning (gst_aravis->camera, &gst_aravis->h_binning, &gst_aravis->v_binning);
+	gst_aravis->payload = 0;
+}
+
 static gboolean
 gst_aravis_start (GstBaseSrc *src)
 {
@@ -253,10 +296,9 @@ gst_aravis_start (GstBaseSrc *src)
 
 	GST_LOG_OBJECT (gst_aravis, "Open camera '%s'", gst_aravis->camera_name);
 
-	if (gst_aravis->camera != NULL)
-		g_object_unref (gst_aravis->camera);
+	if (gst_aravis->camera == NULL)
+		gst_aravis_init_camera (gst_aravis);
 
-	gst_aravis->camera = arv_camera_new (gst_aravis->camera_name);
 	gst_aravis->all_caps = gst_aravis_get_all_camera_caps (gst_aravis);
 
 	return TRUE;
@@ -274,10 +316,6 @@ gboolean gst_aravis_stop( GstBaseSrc * src )
 		gst_aravis->stream = NULL;
 
 	}
-	if (gst_aravis->camera != NULL) {
-		g_object_unref (gst_aravis->camera);
-		gst_aravis->camera = NULL;
-	}
 	if (gst_aravis->all_caps != NULL) {
 		gst_caps_unref (gst_aravis->all_caps);
 		gst_aravis->all_caps = NULL;
@@ -341,7 +379,7 @@ gst_aravis_create (GstPushSrc * push_src, GstBuffer ** buffer)
 		gst_row_stride = (arv_row_stride & ~(0x3)) + 4;
 
 		size = arv_buffer->height * gst_row_stride;
-		data = g_malloc (size);	
+		data = g_malloc (size);
 
 		for (i = 0; i < arv_buffer->height; i++)
 			memcpy (((char *) data) + i * gst_row_stride, ((char *) arv_buffer->data) + i * arv_row_stride, arv_row_stride);
@@ -355,16 +393,18 @@ gst_aravis_create (GstPushSrc * push_src, GstBuffer ** buffer)
 		GST_BUFFER_SIZE (*buffer) = arv_buffer->size;
 	}
 
-	if (gst_aravis->timestamp_offset == 0) {
-		gst_aravis->timestamp_offset = arv_buffer->timestamp_ns;
+	if (!gst_base_src_get_do_timestamp(GST_BASE_SRC(push_src))) {
+		if (gst_aravis->timestamp_offset == 0) {
+			gst_aravis->timestamp_offset = arv_buffer->timestamp_ns;
+			gst_aravis->last_timestamp = arv_buffer->timestamp_ns;
+		}
+
+		GST_BUFFER_TIMESTAMP (*buffer) = arv_buffer->timestamp_ns - gst_aravis->timestamp_offset;
+		GST_BUFFER_DURATION (*buffer) = arv_buffer->timestamp_ns - gst_aravis->last_timestamp;
+
 		gst_aravis->last_timestamp = arv_buffer->timestamp_ns;
 	}
 
-	GST_BUFFER_TIMESTAMP (*buffer) = arv_buffer->timestamp_ns - gst_aravis->timestamp_offset;
-	GST_BUFFER_DURATION (*buffer) = arv_buffer->timestamp_ns - gst_aravis->last_timestamp;
-
-	gst_aravis->last_timestamp = arv_buffer->timestamp_ns;
-
 	arv_stream_push_buffer (gst_aravis->stream, arv_buffer);
 
 	gst_buffer_set_caps (*buffer, gst_aravis->fixed_caps);
@@ -464,22 +504,35 @@ gst_aravis_set_property (GObject * object, guint prop_id,
 	switch (prop_id) {
 		case PROP_CAMERA_NAME:
 			g_free (gst_aravis->camera_name);
-			gst_aravis->camera_name = g_strdup (g_value_get_string (value));
+			/* check if we are currently active
+			   prevent setting camera and other values to something not representing the active camera */
+			if (gst_aravis->stream == NULL) {
+				gst_aravis->camera_name = g_strdup (g_value_get_string (value));
+				gst_aravis_init_camera (gst_aravis);
+			}
 
 			GST_LOG_OBJECT (gst_aravis, "Set camera name to %s", gst_aravis->camera_name);
 
 			break;
 		case PROP_GAIN:
-			gst_aravis->gain = g_value_get_int (value);
+			gst_aravis->gain = g_value_get_double (value);
+			if (gst_aravis->camera != NULL)
+				arv_camera_set_gain (gst_aravis->camera, gst_aravis->gain);
 			break;
 		case PROP_GAIN_AUTO:
 			gst_aravis->gain_auto = g_value_get_boolean (value);
+			if (gst_aravis->camera != NULL)
+				arv_camera_set_gain_auto (gst_aravis->camera, gst_aravis->gain_auto);
 			break;
 		case PROP_EXPOSURE:
 			gst_aravis->exposure_time_us = g_value_get_double (value);
+			if (gst_aravis->camera != NULL)
+				arv_camera_set_exposure_time (gst_aravis->camera, gst_aravis->exposure_time_us);
 			break;
 		case PROP_EXPOSURE_AUTO:
 			gst_aravis->exposure_auto = g_value_get_boolean (value);
+			if (gst_aravis->camera != NULL)
+				arv_camera_set_exposure_time_auto (gst_aravis->camera, gst_aravis->exposure_auto);
 			break;
 		case PROP_OFFSET_X:
 			gst_aravis->offset_x = g_value_get_int (value);
@@ -509,8 +562,11 @@ gst_aravis_get_property (GObject * object, guint prop_id, GValue * value,
 		case PROP_CAMERA_NAME:
 			g_value_set_string (value, gst_aravis->camera_name);
 			break;
+		case PROP_CAMERA:
+			g_value_set_object (value, gst_aravis->camera);
+			break;
 		case PROP_GAIN:
-			g_value_set_int (value, gst_aravis->gain);
+			g_value_set_double (value, gst_aravis->gain);
 			break;
 		case PROP_GAIN_AUTO:
 			g_value_set_boolean (value, gst_aravis->gain_auto);
@@ -572,13 +628,21 @@ gst_aravis_class_init (GstAravisClass * klass)
 				      "Name of the camera",
 				      NULL,
 				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property
+		(gobject_class,
+		 PROP_CAMERA,
+		 g_param_spec_object ("camera",
+				      "Camera Object",
+				      "Camera instance to retrieve additional information",
+				              ARV_TYPE_CAMERA,
+				      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property
 		(gobject_class,
 		 PROP_GAIN,
-		 g_param_spec_int ("gain",
+		 g_param_spec_double ("gain",
 				   "Gain",
 				   "Gain (dB)",
-				   -1, 500, 0,
+				   -1.0, 500.0, 0.0,
 				   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property
 		(gobject_class,
