@@ -169,8 +169,8 @@ arv_gvsp_packet_to_string (const ArvGvspPacket *packet, size_t packet_size)
 	packet_type = arv_gvsp_packet_get_packet_type (packet);
 	content_type = arv_gvsp_packet_get_content_type (packet);
 
-	g_string_append_printf (string, "packet_type  = %s\n", arv_gvsp_packet_type_to_string (packet_type));
-	g_string_append_printf (string, "content_type = %s\n", arv_gvsp_content_type_to_string (content_type));
+	g_string_append_printf (string, "packet_type  = %s (%04x)\n", arv_gvsp_packet_type_to_string (packet_type), packet_type);
+	g_string_append_printf (string, "content_type = %s (%04x)\n", arv_gvsp_content_type_to_string (content_type), content_type);
 
 	switch (content_type) {
 		case ARV_GVSP_CONTENT_TYPE_DATA_LEADER:
